/*
 *  Copyright (C) 2000 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

void session_autosave(void);
gboolean session_autoresume(void);
void session_save (void);
void session_add_window (GaleonWindow *window);
void session_remove_window (GaleonWindow *window);
void session_quit (gboolean auto_save);
void session_quit_cb (gpointer data);
void session_save_to (const gchar *filename);
void session_load_from (const gchar *filename);
GList *session_history_get (void);
void session_history_add (const gchar *filename);
void session_history_load_index (gint index);

/* quit timeout id */
extern gint quit_timeout_id;
